ZebaUserTracker class


Main Tracker Class

Constructors

ZebaUserTracker()
factory

Properties

funnelTracker FunnelTracker
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getEvents() Future<List<Map<String, dynamic>>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
overridePrefs(SharedPreferences prefs) → void
toString() String
A string representation of this object.
inherited
trackEvent(String eventName, {Map<String, dynamic>? params}) Future<void>
Track any custom event

Operators

operator ==(Object other) bool
The equality operator.
inherited